<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Zestaw dźwięków</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Ścieżki do zestawów</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Test dźwięku</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Odtwórz dźwięk</translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation>Włącz powiadomienia dźwiękowe</translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation>Uzyj własnego dźwięku</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation>Uzyj własnego dźwięku</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Własne</translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation>Odtwarzaj dźwięki</translation>
    </message>
</context>
</TS>